proc import datafile=
	"D:\Julian\Students\Natasha\data\LPS data summary2.csv"     
	out=LPS
    dbms=csv
    replace;
    getnames=yes;
/*
variables: Dam,Diet,born,gotpreg,age_preg,firstmating,matingcollected,weightcheck,treatment,outcome,litter,fetus,placenta,resorptions,attempts, TNFalpha

firstmating	= weight at first mating
matingcollected	= weight at the mating when they were collected
weightcheck	= weight when they were checked for pregnancy on GD6 day before they were injected
attempts = number of times a female was paired with male to become pregnant
TNFalpha = maternal serum TNFalpha at G14 (pg/mL);
*/
proc print;
data foodcons;
	input diet $ calories protein carbohydrate fat; 
	*calories = average kcal/mouse/day; *protein carbohydrate fat = average g/mouse/day;
cards;
HFD	9.909890571	0.502827429	0.858996857	0.502827429
HFD	10.88981143	0.552548571	0.943937143	0.552548571
HFD	13.45685	0.6828	1.16645	0.6828
HFD	11.23226343	0.569924571	0.973621143	0.569924571
HFD	11.72769714	0.595062857	1.016565714	0.595062857
HFD	11.27091429	0.571885714	0.976971429	0.571885714
HFD	12.06420286	0.612137143	1.045734286	0.612137143
HFD	11.84256857	0.600891429	1.026522857	0.600891429
HFD	10.78980571	0.547474286	0.935268571	0.547474286
HFD	12.94128	0.65664	1.12176	0.65664
LFD	9.8054	0.488996571	1.714034857	0.109514857
LFD	9.6811	0.482797714	1.692306571	0.108126571
LFD	9.4127	0.469412571	1.645388857	0.105128857
LFD	10.4005	0.518674286	1.818061429	0.116161429
LFD	10.135125	0.50544	1.7716725	0.1131975
LFD	11.479875	0.572502857	2.006741786	0.128216786
*;
proc glm data = foodcons;
	class diet;
	model calories protein carbohydrate fat = diet/ss3;
	lsmeans diet/ stderr;
	title "average across cages";


proc glm data = LPS;
	class diet;
	model firstmating = diet/ss3;
	lsmeans diet/ stderr;
	title "including all females";

data injection;
	set LPS;
	if treatment = "none" then delete;
	if outcome = "collected" | outcome = "col_not_preg"; *"col_not_preg" = injected at GD7 but no conceptuses on GD14;
	weightgain = weightcheck-matingcollected;

proc sort;
	by diet;
proc freq;
	tables treatment*outcome;
	by diet;
	title "including all females who were injected and collected";

proc freq;
	tables treatment*outcome;
proc logistic;
	class diet treatment;
	model outcome = diet|treatment weightgain;
proc logistic;
	class diet treatment;
	model outcome = diet treatment weightgain;

data collected;
	set LPS;
	if treatment = "none" then delete;
	if outcome = "collected";
	weightloss = firstmating-matingcollected;
	age_preg = log(age_preg);
	weightgain = weightcheck-matingcollected;

proc glm;
	class diet;
	model  age_preg firstmating matingcollected weightloss = diet/ss3;
	lsmeans diet/stderr;
	title "including only females who were pregnant at GD14";

proc means mean median;
	class diet;
	var attempts;
proc npar1way wilcoxon;
	class diet;
	var attempts;
proc glm;
	class diet treatment;
	model fetus placenta = diet|treatment age_preg/ss3;
	lsmeans diet*treatment/stderr;
	estimate "age at pregnancy" age_preg 1;
	estimate "effect of treatment in HFD" treatment -1 1 diet*treatment -1 1 0 0;
	estimate "effect of treatment in LFD" treatment -1 1 diet*treatment 0 0 -1 1;
proc glm;
	class diet treatment;
	model litter resorptions = diet|treatment age_preg/ss3;
	lsmeans diet*treatment/stderr;
	estimate "age at pregnancy" age_preg 1;
proc npar1way wilcoxon;
	class diet;
	var litter resorptions attempts;
proc npar1way wilcoxon;
	class treatment;
	var litter resorptions;
proc glm;
	class diet treatment;
	model TNFalpha = diet|treatment/ss3;
	lsmeans diet*treatment/stderr;
proc npar1way wilcoxon;
	class diet;
	var TNFalpha;
data DIOSvsR;
	set collected;
	if diet = "HFD" then do;
		if firstmating > (22.2636364+ 3*1.3071134) then diet2 = "DIOS"; else diet2 = "DIOR"; end; *use only females who produced pups; *rationale: females who did not produce pups weren't necessarily reflective of healthy weight;
	if diet = "LFD" then diet2 = "LFD";

proc means;
	class diet;
	var firstmating;
proc freq;
	tables treatment*diet2;
	title"analysing DIOR and DIOS females separately";
proc glm;
	class diet2 treatment;
	model fetus placenta = diet2|treatment age_preg/ss3;
	lsmeans diet2*treatment/stderr;
	estimate "age at pregnancy" age_preg 1;
proc glm;
	class diet2 treatment;
	model litter resorptions = diet2|treatment age_preg/ss3;
	lsmeans diet2*treatment/stderr;
	estimate "age at pregnancy" age_preg 1;
proc npar1way wilcoxon;
	class diet2;
	var litter resorptions;

run;
